@@ -390,8 +390,14 @@ bool KTNEFParser::ParserPrivate::parseDevice()
     delete current_;
     current_ = nullptr;
 
-    if (!device_->open(QIODevice::ReadOnly)) {
-        qCDebug(KTNEF_LOG) << "Couldn't open device";
+    if (!device_->isOpen()) {
+        if (!device_->open(QIODevice::ReadOnly)) {
+            qCDebug(KTNEF_LOG) << "Couldn't open device";
+            return false;
+        }
+    }
+    if (!device_->isReadable()) {
+        qCDebug(KTNEF_LOG) << "Device not readable";
         return false;
     }
 
@@ -568,7 +574,7 @@ void KTNEFParser::ParserPrivate::checkCurrent(int key)
                     }
                     if (mimetype.name() == QLatin1String("application/octet-stream") &&
                             current_->size() > 0) {
-                        int oldOffset = device_->pos();
+                        qint64 oldOffset = device_->pos();
                         QByteArray buffer(qMin(32, current_->size()), '\0');
                         device_->seek(current_->offset());
                         device_->read(buffer.data(), buffer.size());
@@ -618,12 +624,11 @@ QDateTime formatTime(quint32 lowB, quint32 highB)
     u64 -= 116444736000000000LL;
     u64 /= 10000000;
     if (u64 <= 0xffffffffU) {
-        dt.setTime_t((unsigned int)u64);
+        dt = QDateTime::fromSecsSinceEpoch((unsigned int)u64);
     } else {
         qCWarning(KTNEF_LOG).nospace() << "Invalid date: low byte="
                                        << showbase << qSetFieldWidth(8) << qSetPadChar(QLatin1Char('0'))
                                        << lowB << ", high byte=" << highB;
-        dt.setTime_t(0xffffffffU);
     }
     return dt;
 }
